declare const worker: {
    onmessage: (this: Window, ev: MessageEvent<any>) => any;
};

/**
 * 調用Worker中的方法。
 *
 * @param funcName 方法名稱。
 * @params params 方法參數。
 * @param workerName 是否在Worker中執行，默認為true。。
 * @returns
 */
declare function callWorkerFunction<K extends keyof WorkerFunctionMap>(funcName: K, params: Parameters<WorkerFunctionMap[K]>, workerName?: string): Promise<{
    /**
     * 返回結果
     */
    result?: ReturnType<WorkerFunctionMap[K]>;
    /**
     * 消耗時間
     */
    cost?: number;
}>;
/**
 * 註冊可在Worker中執行的方法。
 *
 * @param funcName 方法名稱。
 * @param func 方法定義。
 *
 */
declare function registerWorkerFunction<K extends keyof WorkerFunctionMap>(funcName: K, func: WorkerFunctionMap[K]): void;
/**
 * 註冊Worker。
 *
 * @param workerName Worker名稱。
 * @param worker Worker實例。
 *
 */
declare function registerWorker(workerName: string, worker: Worker): void;
/**
 * 注销Worker。
 *
 * @param workerName Worker名稱。
 * @param terminate 是否終止Worker。
 */
declare function ungisterWorker(workerName: string, terminate?: boolean): void;
declare global {
    /**
     * 申明所有需要在Worker中調用的方法。
     */
    interface WorkerFunctionMap {
    }
}

export { callWorkerFunction, registerWorker, registerWorkerFunction, ungisterWorker, worker };
export as namespace feng3d;
